@@ -5,7 +5,6 @@ __docformat__ = 'reStructuredText'
 import urllib.parse as urlparse
 
 import json
-
 import intelligent_plant.http_client as http_client
 
 def normalise_tag_map(tags):
@@ -18,7 +17,7 @@ def normalise_tag_map(tags):
 class DataCoreClient(http_client.HttpClient):
     """Access the Intelligent Plant Data Core API"""
 
-    def __init__(self, authorization_header, base_url = "https://appstore.intelligentplant.com/gestalt/datacore/"):
+    def __init__(self, base_url = "https://appstore.intelligentplant.com/gestalt/datacore/", **kwargs):
         """
         Initialise a data core client with the specified authoriation haeder value and base URL.
         It is recommended that you use AppStoreClient.get_data_core_client(..) rather than calling this directly.
@@ -26,7 +25,7 @@ class DataCoreClient(http_client.HttpClient):
         :param authorization_header: The authorization header that will be used for all requests.
         :param base_url: The base URL to make requests from. The default value is "https://appstore.intelligentplant.com/gestalt/datacore/" (the app store data api)
         """
-        http_client.HttpClient.__init__(self, authorization_header, base_url)
+        super().__init__(base_url, **kwargs)
     
     def get_data_sources(self):
         """
@@ -157,3 +156,17 @@ class DataCoreClient(http_client.HttpClient):
         }
 
         return self.post_json("api/data/v2/history-at-times", json=req)
+
+    def write_snapshot_values(self, dsn, values):
+        """
+        Write a set of tag values into the specified datasource.
+
+        :param dsn: The data source name the values are to be written to.
+        :param values: A list of TagValue Objects that specifiy the values and the time stamps they are to be written at.
+
+        :return: A dictionary of tag names, containg dictionarys of Write Results detailing the success of the write.
+        :raises: :class:`HTTPError`, if one occurred.
+        :raises: An exception if JSON decoding fails.
+        """
+
+        return self.put_json(urlparse.urljoin("api/data/v2/snapshot/", dsn), json=values)
\ No newline at end of file
